Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(41)

Unified Diff: src/ast/scopes.cc

Issue 2368613002: [modules] Simplify treatment of empty imports. (Closed)
Patch Set: Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ast/scopeinfo.cc ('k') | src/objects.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ast/scopes.cc
diff --git a/src/ast/scopes.cc b/src/ast/scopes.cc
index 9c5395a0c32f8d0cf60cbdef436704398e803d03..4d95142d448acf32d7cde4cde603242f88be0b15 100644
--- a/src/ast/scopes.cc
+++ b/src/ast/scopes.cc
@@ -185,12 +185,13 @@ ModuleScope::ModuleScope(Isolate* isolate, Handle<ScopeInfo> scope_info,
module_descriptor_->DeserializeRegularExports(isolate, avfactory,
regular_exports);
- // Deserialize special imports.
- Handle<FixedArray> special_imports(module_info->special_imports(), isolate);
- for (int i = 0, n = special_imports->length(); i < n; ++i) {
+ // Deserialize namespace imports.
+ Handle<FixedArray> namespace_imports(module_info->namespace_imports(),
+ isolate);
+ for (int i = 0, n = namespace_imports->length(); i < n; ++i) {
Handle<ModuleInfoEntry> serialized_entry(
- ModuleInfoEntry::cast(special_imports->get(i)), isolate);
- module_descriptor_->AddSpecialImport(
+ ModuleInfoEntry::cast(namespace_imports->get(i)), isolate);
+ module_descriptor_->AddNamespaceImport(
ModuleDescriptor::Entry::Deserialize(isolate, avfactory,
serialized_entry),
avfactory->zone());
« no previous file with comments | « src/ast/scopeinfo.cc ('k') | src/objects.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698